# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: RobotPose.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import CommonTypes_pb2 as CommonTypes__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='RobotPose.proto',
  package='naothmessages',
  syntax='proto2',
  serialized_pb=_b('\n\x0fRobotPose.proto\x12\rnaothmessages\x1a\x11\x43ommonTypes.proto\"\xb5\x01\n\tRobotPose\x12#\n\x04pose\x18\x01 \x02(\x0b\x32\x15.naothmessages.Pose2D\x12\x0f\n\x07isValid\x18\x02 \x01(\x08\x12\x38\n\x12principleAxisMajor\x18\x03 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12\x38\n\x12principleAxisMinor\x18\x04 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2B\x1b\n\x19\x64\x65.naoth.rc.core.messages')
  ,
  dependencies=[CommonTypes__pb2.DESCRIPTOR,])




_ROBOTPOSE = _descriptor.Descriptor(
  name='RobotPose',
  full_name='naothmessages.RobotPose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pose', full_name='naothmessages.RobotPose.pose', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='isValid', full_name='naothmessages.RobotPose.isValid', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='principleAxisMajor', full_name='naothmessages.RobotPose.principleAxisMajor', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='principleAxisMinor', full_name='naothmessages.RobotPose.principleAxisMinor', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=235,
)

_ROBOTPOSE.fields_by_name['pose'].message_type = CommonTypes__pb2._POSE2D
_ROBOTPOSE.fields_by_name['principleAxisMajor'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_ROBOTPOSE.fields_by_name['principleAxisMinor'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
DESCRIPTOR.message_types_by_name['RobotPose'] = _ROBOTPOSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RobotPose = _reflection.GeneratedProtocolMessageType('RobotPose', (_message.Message,), dict(
  DESCRIPTOR = _ROBOTPOSE,
  __module__ = 'RobotPose_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.RobotPose)
  ))
_sym_db.RegisterMessage(RobotPose)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\031de.naoth.rc.core.messages'))
# @@protoc_insertion_point(module_scope)
