# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Messages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import CommonTypes_pb2 as CommonTypes__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='Messages.proto',
  package='naothmessages',
  syntax='proto2',
  serialized_pb=_b('\n\x0eMessages.proto\x12\rnaothmessages\x1a\x11\x43ommonTypes.proto\"%\n\x06\x43MDArg\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\r\n\x05\x62ytes\x18\x03 \x01(\x0c\"8\n\x03\x43MD\x12\x0c\n\x04name\x18\x01 \x02(\t\x12#\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x15.naothmessages.CMDArg\"+\n\rStopwatchItem\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0c\n\x04time\x18\x02 \x02(\r\"@\n\x0bStopwatches\x12\x31\n\x0bstopwatches\x18\x01 \x03(\x0b\x32\x1c.naothmessages.StopwatchItem\"\xb2\x01\n\x08PlotItem\x12.\n\x04type\x18\x01 \x02(\x0e\x32 .naothmessages.PlotItem.PlotType\x12\x0c\n\x04name\x18\x02 \x02(\t\x12\r\n\x05value\x18\x03 \x01(\x01\x12\t\n\x01x\x18\x04 \x01(\x01\x12\t\n\x01y\x18\x05 \x01(\x01\x12\x10\n\x08rotation\x18\x06 \x01(\x01\"1\n\x08PlotType\x12\x0b\n\x07\x44\x65\x66\x61ult\x10\x01\x12\n\n\x06Plot2D\x10\x02\x12\x0c\n\x08Origin2D\x10\x03\"J\n\x0cPlotStroke2D\x12\x0c\n\x04name\x18\x02 \x02(\t\x12,\n\x06points\x18\x01 \x03(\x0b\x32\x1c.naothmessages.DoubleVector2\"a\n\x05Plots\x12&\n\x05plots\x18\x01 \x03(\x0b\x32\x17.naothmessages.PlotItem\x12\x30\n\x0bplotstrokes\x18\x02 \x03(\x0b\x32\x1b.naothmessages.PlotStroke2D\"\xf8\x01\n\x0bXABSLSymbol\x12\x0e\n\x02id\x18\x01 \x02(\x05:\x02-1\x12<\n\x04type\x18\x02 \x02(\x0e\x32%.naothmessages.XABSLSymbol.SymbolType:\x07Unknown\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x14\n\x0c\x64\x65\x63imalValue\x18\x0b \x01(\x01\x12\x11\n\tboolValue\x18\x0c \x01(\x08\x12\x11\n\tenumValue\x18\r \x01(\x05\x12\x12\n\nenumTypeId\x18\x0e \x01(\x05\"=\n\nSymbolType\x12\x0b\n\x07\x44\x65\x63imal\x10\x00\x12\x0b\n\x07\x42oolean\x10\x01\x12\x08\n\x04\x45num\x10\x02\x12\x0b\n\x07Unknown\x10\x03\"\xfd\x01\n\x17XABSLActiveOptionSparse\x12\x0e\n\x02id\x18\x01 \x02(\x05:\x02-1\x12\x1a\n\x0ftimeOfExecution\x18\x03 \x01(\x03:\x01\x30\x12\x13\n\x0b\x61\x63tiveState\x18\x04 \x01(\x05\x12\x11\n\tstateTime\x18\x05 \x01(\x03\x12\x19\n\x11\x64\x65\x63imalParameters\x18\x06 \x03(\x01\x12\x19\n\x11\x62ooleanParameters\x18\x07 \x03(\x08\x12\x1c\n\x14\x65numeratedParameters\x18\x08 \x03(\x05\x12:\n\x10\x61\x63tiveSubActions\x18\t \x03(\x0b\x32 .naothmessages.XABSLActionSparse\"\x8b\x02\n\x11XABSLActionSparse\x12\x42\n\x04type\x18\x02 \x02(\x0e\x32+.naothmessages.XABSLActionSparse.ActionType:\x07Unknown\x12*\n\x06symbol\x18\x03 \x01(\x0b\x32\x1a.naothmessages.XABSLSymbol\x12\x36\n\x06option\x18\x04 \x01(\x0b\x32&.naothmessages.XABSLActiveOptionSparse\"N\n\nActionType\x12\n\n\x06Option\x10\x00\x12\x11\n\rBasicBehavior\x10\x01\x12\x14\n\x10SymbolAssignment\x10\x02\x12\x0b\n\x07Unknown\x10\x03\"\x93\x03\n\x0fSymbolValueList\x12<\n\x07\x64\x65\x63imal\x18\x01 \x03(\x0b\x32+.naothmessages.SymbolValueList.DoubleSymbol\x12=\n\x07\x62oolean\x18\x02 \x03(\x0b\x32,.naothmessages.SymbolValueList.BooleanSymbol\x12=\n\nenumerated\x18\x03 \x03(\x0b\x32).naothmessages.SymbolValueList.EnumSymbol\x1a;\n\x0c\x44oubleSymbol\x12\x0e\n\x02id\x18\x01 \x02(\x05:\x02-1\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\x01\x1a<\n\rBooleanSymbol\x12\x0e\n\x02id\x18\x01 \x02(\x05:\x02-1\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\x08\x1aI\n\nEnumSymbol\x12\x0e\n\x02id\x18\x01 \x02(\x05:\x02-1\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\r \x01(\x05\x12\x0e\n\x06typeId\x18\x0e \x01(\x05\"\xff\x01\n\x13\x42\x65haviorStateSparse\x12\r\n\x05\x61gent\x18\x01 \x01(\t\x12;\n\x11\x61\x63tiveRootActions\x18\x02 \x03(\x0b\x32 .naothmessages.XABSLActionSparse\x12\x37\n\x0finputSymbolList\x18\n \x01(\x0b\x32\x1e.naothmessages.SymbolValueList\x12\x38\n\x10outputSymbolList\x18\x0b \x01(\x0b\x32\x1e.naothmessages.SymbolValueList\x12\x13\n\x0b\x66rameNumber\x18\x05 \x01(\r\x12\x14\n\x0c\x65rrorMessage\x18\x06 \x01(\t\"\xc8\x05\n\x15\x42\x65haviorStateComplete\x12\x43\n\x0c\x65numerations\x18\n \x03(\x0b\x32-.naothmessages.BehaviorStateComplete.EnumType\x12<\n\x07options\x18\x0b \x03(\x0b\x32+.naothmessages.BehaviorStateComplete.Option\x12:\n\x06\x61gents\x18\x0c \x03(\x0b\x32*.naothmessages.BehaviorStateComplete.Agent\x12\x37\n\x0finputSymbolList\x18\r \x01(\x0b\x32\x1e.naothmessages.SymbolValueList\x12\x38\n\x10outputSymbolList\x18\x0e \x01(\x0b\x32\x1e.naothmessages.SymbolValueList\x12\x13\n\x0b\x66rameNumber\x18\x0f \x01(\r\x1a\x89\x01\n\x08\x45numType\x12\x0c\n\x04name\x18\x01 \x02(\t\x12G\n\x08\x65lements\x18\x02 \x03(\x0b\x32\x35.naothmessages.BehaviorStateComplete.EnumType.Element\x1a&\n\x07\x45lement\x12\r\n\x05value\x18\x01 \x02(\x05\x12\x0c\n\x04name\x18\x02 \x02(\t\x1a\xb0\x01\n\x06Option\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x41\n\x06states\x18\x03 \x03(\x0b\x32\x31.naothmessages.BehaviorStateComplete.Option.State\x12.\n\nparameters\x18\x02 \x03(\x0b\x32\x1a.naothmessages.XABSLSymbol\x1a%\n\x05State\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0e\n\x06target\x18\x02 \x01(\x08\x1a)\n\x05\x41gent\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x12\n\nrootOption\x18\x02 \x02(\t\"k\n\x06Module\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x1b\n\x13usedRepresentations\x18\x02 \x03(\t\x12\x1f\n\x17providedRepresentations\x18\x03 \x03(\t\x12\x15\n\x06\x61\x63tive\x18\x04 \x01(\x08:\x05\x66\x61lse\"4\n\nModuleList\x12&\n\x07modules\x18\x01 \x03(\x0b\x32\x15.naothmessages.Module\"\x83\x01\n\x0c\x44\x65\x62ugRequest\x12\x32\n\x08requests\x18\x01 \x03(\x0b\x32 .naothmessages.DebugRequest.Item\x1a?\n\x04Item\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x14\n\x05value\x18\x04 \x02(\x08:\x05\x66\x61lse\"\x8b\x01\n\x0f\x46\x65\x61tureKeyPoint\x12\'\n\x02pt\x18\x01 \x02(\x0b\x32\x1b.naothmessages.FloatVector2\x12\x0c\n\x04size\x18\x02 \x02(\x02\x12\r\n\x05\x61ngle\x18\x03 \x02(\x02\x12\x10\n\x08response\x18\x04 \x02(\x02\x12\x0e\n\x06octave\x18\x05 \x02(\x05\x12\x10\n\x08\x63lass_id\x18\x06 \x02(\x05\"\xd9\x01\n\x16\x46\x65\x61tureDetectionResult\x12\x16\n\x0egrayScaleImage\x18\x01 \x02(\x0c\x12\x31\n\tkeyPoints\x18\x02 \x03(\x0b\x32\x1e.naothmessages.FeatureKeyPoint\x12\x34\n\x0b\x64\x65scriptors\x18\x03 \x03(\x0b\x32\x1f.naothmessages.SingleDescriptor\x12\x19\n\x11namesForKeyPoints\x18\x04 \x03(\t\x12#\n\x17numberOfFeatureElements\x18\x05 \x01(\x05:\x02\x36\x34\"\x1d\n\x10SingleDescriptor\x12\t\n\x01\x64\x18\x01 \x03(\x02\"d\n\x0c\x46\x65\x61tureClass\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x30\n\x07samples\x18\x02 \x03(\x0b\x32\x1f.naothmessages.SingleDescriptor\x12\x14\n\x0cobjectHeight\x18\x03 \x01(\x01\"a\n\x0c\x46\x65\x61tureTable\x12,\n\x07\x63lasses\x18\x01 \x03(\x0b\x32\x1b.naothmessages.FeatureClass\x12#\n\x17numberOfFeatureElements\x18\x02 \x01(\x05:\x02\x36\x34\x42\x1b\n\x19\x64\x65.naoth.rc.core.messages')
  ,
  dependencies=[CommonTypes__pb2.DESCRIPTOR,])



_PLOTITEM_PLOTTYPE = _descriptor.EnumDescriptor(
  name='PlotType',
  full_name='naothmessages.PlotItem.PlotType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Default', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Plot2D', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Origin2D', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=390,
  serialized_end=439,
)
_sym_db.RegisterEnumDescriptor(_PLOTITEM_PLOTTYPE)

_XABSLSYMBOL_SYMBOLTYPE = _descriptor.EnumDescriptor(
  name='SymbolType',
  full_name='naothmessages.XABSLSymbol.SymbolType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Decimal', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Boolean', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Enum', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Unknown', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=804,
  serialized_end=865,
)
_sym_db.RegisterEnumDescriptor(_XABSLSYMBOL_SYMBOLTYPE)

_XABSLACTIONSPARSE_ACTIONTYPE = _descriptor.EnumDescriptor(
  name='ActionType',
  full_name='naothmessages.XABSLActionSparse.ActionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Option', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BasicBehavior', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SymbolAssignment', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Unknown', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1313,
  serialized_end=1391,
)
_sym_db.RegisterEnumDescriptor(_XABSLACTIONSPARSE_ACTIONTYPE)


_CMDARG = _descriptor.Descriptor(
  name='CMDArg',
  full_name='naothmessages.CMDArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='naothmessages.CMDArg.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bytes', full_name='naothmessages.CMDArg.bytes', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=89,
)


_CMD = _descriptor.Descriptor(
  name='CMD',
  full_name='naothmessages.CMD',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='naothmessages.CMD.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='args', full_name='naothmessages.CMD.args', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=91,
  serialized_end=147,
)


_STOPWATCHITEM = _descriptor.Descriptor(
  name='StopwatchItem',
  full_name='naothmessages.StopwatchItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='naothmessages.StopwatchItem.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time', full_name='naothmessages.StopwatchItem.time', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=192,
)


_STOPWATCHES = _descriptor.Descriptor(
  name='Stopwatches',
  full_name='naothmessages.Stopwatches',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stopwatches', full_name='naothmessages.Stopwatches.stopwatches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=194,
  serialized_end=258,
)


_PLOTITEM = _descriptor.Descriptor(
  name='PlotItem',
  full_name='naothmessages.PlotItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='naothmessages.PlotItem.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='naothmessages.PlotItem.name', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='naothmessages.PlotItem.value', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='x', full_name='naothmessages.PlotItem.x', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='naothmessages.PlotItem.y', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rotation', full_name='naothmessages.PlotItem.rotation', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PLOTITEM_PLOTTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=261,
  serialized_end=439,
)


_PLOTSTROKE2D = _descriptor.Descriptor(
  name='PlotStroke2D',
  full_name='naothmessages.PlotStroke2D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='naothmessages.PlotStroke2D.name', index=0,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='points', full_name='naothmessages.PlotStroke2D.points', index=1,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=441,
  serialized_end=515,
)


_PLOTS = _descriptor.Descriptor(
  name='Plots',
  full_name='naothmessages.Plots',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plots', full_name='naothmessages.Plots.plots', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='plotstrokes', full_name='naothmessages.Plots.plotstrokes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=517,
  serialized_end=614,
)


_XABSLSYMBOL = _descriptor.Descriptor(
  name='XABSLSymbol',
  full_name='naothmessages.XABSLSymbol',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='naothmessages.XABSLSymbol.id', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='naothmessages.XABSLSymbol.type', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='naothmessages.XABSLSymbol.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='decimalValue', full_name='naothmessages.XABSLSymbol.decimalValue', index=3,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='boolValue', full_name='naothmessages.XABSLSymbol.boolValue', index=4,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='enumValue', full_name='naothmessages.XABSLSymbol.enumValue', index=5,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='enumTypeId', full_name='naothmessages.XABSLSymbol.enumTypeId', index=6,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _XABSLSYMBOL_SYMBOLTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=865,
)


_XABSLACTIVEOPTIONSPARSE = _descriptor.Descriptor(
  name='XABSLActiveOptionSparse',
  full_name='naothmessages.XABSLActiveOptionSparse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='naothmessages.XABSLActiveOptionSparse.id', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timeOfExecution', full_name='naothmessages.XABSLActiveOptionSparse.timeOfExecution', index=1,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='activeState', full_name='naothmessages.XABSLActiveOptionSparse.activeState', index=2,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stateTime', full_name='naothmessages.XABSLActiveOptionSparse.stateTime', index=3,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='decimalParameters', full_name='naothmessages.XABSLActiveOptionSparse.decimalParameters', index=4,
      number=6, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='booleanParameters', full_name='naothmessages.XABSLActiveOptionSparse.booleanParameters', index=5,
      number=7, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='enumeratedParameters', full_name='naothmessages.XABSLActiveOptionSparse.enumeratedParameters', index=6,
      number=8, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='activeSubActions', full_name='naothmessages.XABSLActiveOptionSparse.activeSubActions', index=7,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=868,
  serialized_end=1121,
)


_XABSLACTIONSPARSE = _descriptor.Descriptor(
  name='XABSLActionSparse',
  full_name='naothmessages.XABSLActionSparse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='naothmessages.XABSLActionSparse.type', index=0,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='naothmessages.XABSLActionSparse.symbol', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='option', full_name='naothmessages.XABSLActionSparse.option', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _XABSLACTIONSPARSE_ACTIONTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1124,
  serialized_end=1391,
)


_SYMBOLVALUELIST_DOUBLESYMBOL = _descriptor.Descriptor(
  name='DoubleSymbol',
  full_name='naothmessages.SymbolValueList.DoubleSymbol',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='naothmessages.SymbolValueList.DoubleSymbol.id', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='naothmessages.SymbolValueList.DoubleSymbol.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='naothmessages.SymbolValueList.DoubleSymbol.value', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1601,
  serialized_end=1660,
)

_SYMBOLVALUELIST_BOOLEANSYMBOL = _descriptor.Descriptor(
  name='BooleanSymbol',
  full_name='naothmessages.SymbolValueList.BooleanSymbol',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='naothmessages.SymbolValueList.BooleanSymbol.id', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='naothmessages.SymbolValueList.BooleanSymbol.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='naothmessages.SymbolValueList.BooleanSymbol.value', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1662,
  serialized_end=1722,
)

_SYMBOLVALUELIST_ENUMSYMBOL = _descriptor.Descriptor(
  name='EnumSymbol',
  full_name='naothmessages.SymbolValueList.EnumSymbol',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='naothmessages.SymbolValueList.EnumSymbol.id', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='naothmessages.SymbolValueList.EnumSymbol.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='naothmessages.SymbolValueList.EnumSymbol.value', index=2,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='typeId', full_name='naothmessages.SymbolValueList.EnumSymbol.typeId', index=3,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1724,
  serialized_end=1797,
)

_SYMBOLVALUELIST = _descriptor.Descriptor(
  name='SymbolValueList',
  full_name='naothmessages.SymbolValueList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='decimal', full_name='naothmessages.SymbolValueList.decimal', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='boolean', full_name='naothmessages.SymbolValueList.boolean', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='enumerated', full_name='naothmessages.SymbolValueList.enumerated', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_SYMBOLVALUELIST_DOUBLESYMBOL, _SYMBOLVALUELIST_BOOLEANSYMBOL, _SYMBOLVALUELIST_ENUMSYMBOL, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1394,
  serialized_end=1797,
)


_BEHAVIORSTATESPARSE = _descriptor.Descriptor(
  name='BehaviorStateSparse',
  full_name='naothmessages.BehaviorStateSparse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='agent', full_name='naothmessages.BehaviorStateSparse.agent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='activeRootActions', full_name='naothmessages.BehaviorStateSparse.activeRootActions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inputSymbolList', full_name='naothmessages.BehaviorStateSparse.inputSymbolList', index=2,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='outputSymbolList', full_name='naothmessages.BehaviorStateSparse.outputSymbolList', index=3,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frameNumber', full_name='naothmessages.BehaviorStateSparse.frameNumber', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='errorMessage', full_name='naothmessages.BehaviorStateSparse.errorMessage', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1800,
  serialized_end=2055,
)


_BEHAVIORSTATECOMPLETE_ENUMTYPE_ELEMENT = _descriptor.Descriptor(
  name='Element',
  full_name='naothmessages.BehaviorStateComplete.EnumType.Element',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='naothmessages.BehaviorStateComplete.EnumType.Element.value', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='naothmessages.BehaviorStateComplete.EnumType.Element.name', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2510,
  serialized_end=2548,
)

_BEHAVIORSTATECOMPLETE_ENUMTYPE = _descriptor.Descriptor(
  name='EnumType',
  full_name='naothmessages.BehaviorStateComplete.EnumType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='naothmessages.BehaviorStateComplete.EnumType.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='elements', full_name='naothmessages.BehaviorStateComplete.EnumType.elements', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_BEHAVIORSTATECOMPLETE_ENUMTYPE_ELEMENT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2411,
  serialized_end=2548,
)

_BEHAVIORSTATECOMPLETE_OPTION_STATE = _descriptor.Descriptor(
  name='State',
  full_name='naothmessages.BehaviorStateComplete.Option.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='naothmessages.BehaviorStateComplete.Option.State.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target', full_name='naothmessages.BehaviorStateComplete.Option.State.target', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2690,
  serialized_end=2727,
)

_BEHAVIORSTATECOMPLETE_OPTION = _descriptor.Descriptor(
  name='Option',
  full_name='naothmessages.BehaviorStateComplete.Option',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='naothmessages.BehaviorStateComplete.Option.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='states', full_name='naothmessages.BehaviorStateComplete.Option.states', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='naothmessages.BehaviorStateComplete.Option.parameters', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_BEHAVIORSTATECOMPLETE_OPTION_STATE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2551,
  serialized_end=2727,
)

_BEHAVIORSTATECOMPLETE_AGENT = _descriptor.Descriptor(
  name='Agent',
  full_name='naothmessages.BehaviorStateComplete.Agent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='naothmessages.BehaviorStateComplete.Agent.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rootOption', full_name='naothmessages.BehaviorStateComplete.Agent.rootOption', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2729,
  serialized_end=2770,
)

_BEHAVIORSTATECOMPLETE = _descriptor.Descriptor(
  name='BehaviorStateComplete',
  full_name='naothmessages.BehaviorStateComplete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enumerations', full_name='naothmessages.BehaviorStateComplete.enumerations', index=0,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='options', full_name='naothmessages.BehaviorStateComplete.options', index=1,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='agents', full_name='naothmessages.BehaviorStateComplete.agents', index=2,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inputSymbolList', full_name='naothmessages.BehaviorStateComplete.inputSymbolList', index=3,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='outputSymbolList', full_name='naothmessages.BehaviorStateComplete.outputSymbolList', index=4,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frameNumber', full_name='naothmessages.BehaviorStateComplete.frameNumber', index=5,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_BEHAVIORSTATECOMPLETE_ENUMTYPE, _BEHAVIORSTATECOMPLETE_OPTION, _BEHAVIORSTATECOMPLETE_AGENT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2058,
  serialized_end=2770,
)


_MODULE = _descriptor.Descriptor(
  name='Module',
  full_name='naothmessages.Module',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='naothmessages.Module.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='usedRepresentations', full_name='naothmessages.Module.usedRepresentations', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='providedRepresentations', full_name='naothmessages.Module.providedRepresentations', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='active', full_name='naothmessages.Module.active', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2772,
  serialized_end=2879,
)


_MODULELIST = _descriptor.Descriptor(
  name='ModuleList',
  full_name='naothmessages.ModuleList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='modules', full_name='naothmessages.ModuleList.modules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2881,
  serialized_end=2933,
)


_DEBUGREQUEST_ITEM = _descriptor.Descriptor(
  name='Item',
  full_name='naothmessages.DebugRequest.Item',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='naothmessages.DebugRequest.Item.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='naothmessages.DebugRequest.Item.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='naothmessages.DebugRequest.Item.value', index=2,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3004,
  serialized_end=3067,
)

_DEBUGREQUEST = _descriptor.Descriptor(
  name='DebugRequest',
  full_name='naothmessages.DebugRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='requests', full_name='naothmessages.DebugRequest.requests', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_DEBUGREQUEST_ITEM, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2936,
  serialized_end=3067,
)


_FEATUREKEYPOINT = _descriptor.Descriptor(
  name='FeatureKeyPoint',
  full_name='naothmessages.FeatureKeyPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pt', full_name='naothmessages.FeatureKeyPoint.pt', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='size', full_name='naothmessages.FeatureKeyPoint.size', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='angle', full_name='naothmessages.FeatureKeyPoint.angle', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='response', full_name='naothmessages.FeatureKeyPoint.response', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='octave', full_name='naothmessages.FeatureKeyPoint.octave', index=4,
      number=5, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='class_id', full_name='naothmessages.FeatureKeyPoint.class_id', index=5,
      number=6, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3070,
  serialized_end=3209,
)


_FEATUREDETECTIONRESULT = _descriptor.Descriptor(
  name='FeatureDetectionResult',
  full_name='naothmessages.FeatureDetectionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='grayScaleImage', full_name='naothmessages.FeatureDetectionResult.grayScaleImage', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='keyPoints', full_name='naothmessages.FeatureDetectionResult.keyPoints', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='descriptors', full_name='naothmessages.FeatureDetectionResult.descriptors', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='namesForKeyPoints', full_name='naothmessages.FeatureDetectionResult.namesForKeyPoints', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='numberOfFeatureElements', full_name='naothmessages.FeatureDetectionResult.numberOfFeatureElements', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=64,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3212,
  serialized_end=3429,
)


_SINGLEDESCRIPTOR = _descriptor.Descriptor(
  name='SingleDescriptor',
  full_name='naothmessages.SingleDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='d', full_name='naothmessages.SingleDescriptor.d', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3431,
  serialized_end=3460,
)


_FEATURECLASS = _descriptor.Descriptor(
  name='FeatureClass',
  full_name='naothmessages.FeatureClass',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='naothmessages.FeatureClass.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='samples', full_name='naothmessages.FeatureClass.samples', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='objectHeight', full_name='naothmessages.FeatureClass.objectHeight', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3462,
  serialized_end=3562,
)


_FEATURETABLE = _descriptor.Descriptor(
  name='FeatureTable',
  full_name='naothmessages.FeatureTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='classes', full_name='naothmessages.FeatureTable.classes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='numberOfFeatureElements', full_name='naothmessages.FeatureTable.numberOfFeatureElements', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=64,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3564,
  serialized_end=3661,
)

_CMD.fields_by_name['args'].message_type = _CMDARG
_STOPWATCHES.fields_by_name['stopwatches'].message_type = _STOPWATCHITEM
_PLOTITEM.fields_by_name['type'].enum_type = _PLOTITEM_PLOTTYPE
_PLOTITEM_PLOTTYPE.containing_type = _PLOTITEM
_PLOTSTROKE2D.fields_by_name['points'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_PLOTS.fields_by_name['plots'].message_type = _PLOTITEM
_PLOTS.fields_by_name['plotstrokes'].message_type = _PLOTSTROKE2D
_XABSLSYMBOL.fields_by_name['type'].enum_type = _XABSLSYMBOL_SYMBOLTYPE
_XABSLSYMBOL_SYMBOLTYPE.containing_type = _XABSLSYMBOL
_XABSLACTIVEOPTIONSPARSE.fields_by_name['activeSubActions'].message_type = _XABSLACTIONSPARSE
_XABSLACTIONSPARSE.fields_by_name['type'].enum_type = _XABSLACTIONSPARSE_ACTIONTYPE
_XABSLACTIONSPARSE.fields_by_name['symbol'].message_type = _XABSLSYMBOL
_XABSLACTIONSPARSE.fields_by_name['option'].message_type = _XABSLACTIVEOPTIONSPARSE
_XABSLACTIONSPARSE_ACTIONTYPE.containing_type = _XABSLACTIONSPARSE
_SYMBOLVALUELIST_DOUBLESYMBOL.containing_type = _SYMBOLVALUELIST
_SYMBOLVALUELIST_BOOLEANSYMBOL.containing_type = _SYMBOLVALUELIST
_SYMBOLVALUELIST_ENUMSYMBOL.containing_type = _SYMBOLVALUELIST
_SYMBOLVALUELIST.fields_by_name['decimal'].message_type = _SYMBOLVALUELIST_DOUBLESYMBOL
_SYMBOLVALUELIST.fields_by_name['boolean'].message_type = _SYMBOLVALUELIST_BOOLEANSYMBOL
_SYMBOLVALUELIST.fields_by_name['enumerated'].message_type = _SYMBOLVALUELIST_ENUMSYMBOL
_BEHAVIORSTATESPARSE.fields_by_name['activeRootActions'].message_type = _XABSLACTIONSPARSE
_BEHAVIORSTATESPARSE.fields_by_name['inputSymbolList'].message_type = _SYMBOLVALUELIST
_BEHAVIORSTATESPARSE.fields_by_name['outputSymbolList'].message_type = _SYMBOLVALUELIST
_BEHAVIORSTATECOMPLETE_ENUMTYPE_ELEMENT.containing_type = _BEHAVIORSTATECOMPLETE_ENUMTYPE
_BEHAVIORSTATECOMPLETE_ENUMTYPE.fields_by_name['elements'].message_type = _BEHAVIORSTATECOMPLETE_ENUMTYPE_ELEMENT
_BEHAVIORSTATECOMPLETE_ENUMTYPE.containing_type = _BEHAVIORSTATECOMPLETE
_BEHAVIORSTATECOMPLETE_OPTION_STATE.containing_type = _BEHAVIORSTATECOMPLETE_OPTION
_BEHAVIORSTATECOMPLETE_OPTION.fields_by_name['states'].message_type = _BEHAVIORSTATECOMPLETE_OPTION_STATE
_BEHAVIORSTATECOMPLETE_OPTION.fields_by_name['parameters'].message_type = _XABSLSYMBOL
_BEHAVIORSTATECOMPLETE_OPTION.containing_type = _BEHAVIORSTATECOMPLETE
_BEHAVIORSTATECOMPLETE_AGENT.containing_type = _BEHAVIORSTATECOMPLETE
_BEHAVIORSTATECOMPLETE.fields_by_name['enumerations'].message_type = _BEHAVIORSTATECOMPLETE_ENUMTYPE
_BEHAVIORSTATECOMPLETE.fields_by_name['options'].message_type = _BEHAVIORSTATECOMPLETE_OPTION
_BEHAVIORSTATECOMPLETE.fields_by_name['agents'].message_type = _BEHAVIORSTATECOMPLETE_AGENT
_BEHAVIORSTATECOMPLETE.fields_by_name['inputSymbolList'].message_type = _SYMBOLVALUELIST
_BEHAVIORSTATECOMPLETE.fields_by_name['outputSymbolList'].message_type = _SYMBOLVALUELIST
_MODULELIST.fields_by_name['modules'].message_type = _MODULE
_DEBUGREQUEST_ITEM.containing_type = _DEBUGREQUEST
_DEBUGREQUEST.fields_by_name['requests'].message_type = _DEBUGREQUEST_ITEM
_FEATUREKEYPOINT.fields_by_name['pt'].message_type = CommonTypes__pb2._FLOATVECTOR2
_FEATUREDETECTIONRESULT.fields_by_name['keyPoints'].message_type = _FEATUREKEYPOINT
_FEATUREDETECTIONRESULT.fields_by_name['descriptors'].message_type = _SINGLEDESCRIPTOR
_FEATURECLASS.fields_by_name['samples'].message_type = _SINGLEDESCRIPTOR
_FEATURETABLE.fields_by_name['classes'].message_type = _FEATURECLASS
DESCRIPTOR.message_types_by_name['CMDArg'] = _CMDARG
DESCRIPTOR.message_types_by_name['CMD'] = _CMD
DESCRIPTOR.message_types_by_name['StopwatchItem'] = _STOPWATCHITEM
DESCRIPTOR.message_types_by_name['Stopwatches'] = _STOPWATCHES
DESCRIPTOR.message_types_by_name['PlotItem'] = _PLOTITEM
DESCRIPTOR.message_types_by_name['PlotStroke2D'] = _PLOTSTROKE2D
DESCRIPTOR.message_types_by_name['Plots'] = _PLOTS
DESCRIPTOR.message_types_by_name['XABSLSymbol'] = _XABSLSYMBOL
DESCRIPTOR.message_types_by_name['XABSLActiveOptionSparse'] = _XABSLACTIVEOPTIONSPARSE
DESCRIPTOR.message_types_by_name['XABSLActionSparse'] = _XABSLACTIONSPARSE
DESCRIPTOR.message_types_by_name['SymbolValueList'] = _SYMBOLVALUELIST
DESCRIPTOR.message_types_by_name['BehaviorStateSparse'] = _BEHAVIORSTATESPARSE
DESCRIPTOR.message_types_by_name['BehaviorStateComplete'] = _BEHAVIORSTATECOMPLETE
DESCRIPTOR.message_types_by_name['Module'] = _MODULE
DESCRIPTOR.message_types_by_name['ModuleList'] = _MODULELIST
DESCRIPTOR.message_types_by_name['DebugRequest'] = _DEBUGREQUEST
DESCRIPTOR.message_types_by_name['FeatureKeyPoint'] = _FEATUREKEYPOINT
DESCRIPTOR.message_types_by_name['FeatureDetectionResult'] = _FEATUREDETECTIONRESULT
DESCRIPTOR.message_types_by_name['SingleDescriptor'] = _SINGLEDESCRIPTOR
DESCRIPTOR.message_types_by_name['FeatureClass'] = _FEATURECLASS
DESCRIPTOR.message_types_by_name['FeatureTable'] = _FEATURETABLE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CMDArg = _reflection.GeneratedProtocolMessageType('CMDArg', (_message.Message,), dict(
  DESCRIPTOR = _CMDARG,
  __module__ = 'Messages_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.CMDArg)
  ))
_sym_db.RegisterMessage(CMDArg)

CMD = _reflection.GeneratedProtocolMessageType('CMD', (_message.Message,), dict(
  DESCRIPTOR = _CMD,
  __module__ = 'Messages_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.CMD)
  ))
_sym_db.RegisterMessage(CMD)

StopwatchItem = _reflection.GeneratedProtocolMessageType('StopwatchItem', (_message.Message,), dict(
  DESCRIPTOR = _STOPWATCHITEM,
  __module__ = 'Messages_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.StopwatchItem)
  ))
_sym_db.RegisterMessage(StopwatchItem)

Stopwatches = _reflection.GeneratedProtocolMessageType('Stopwatches', (_message.Message,), dict(
  DESCRIPTOR = _STOPWATCHES,
  __module__ = 'Messages_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.Stopwatches)
  ))
_sym_db.RegisterMessage(Stopwatches)

PlotItem = _reflection.GeneratedProtocolMessageType('PlotItem', (_message.Message,), dict(
  DESCRIPTOR = _PLOTITEM,
  __module__ = 'Messages_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.PlotItem)
  ))
_sym_db.RegisterMessage(PlotItem)

PlotStroke2D = _reflection.GeneratedProtocolMessageType('PlotStroke2D', (_message.Message,), dict(
  DESCRIPTOR = _PLOTSTROKE2D,
  __module__ = 'Messages_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.PlotStroke2D)
  ))
_sym_db.RegisterMessage(PlotStroke2D)

Plots = _reflection.GeneratedProtocolMessageType('Plots', (_message.Message,), dict(
  DESCRIPTOR = _PLOTS,
  __module__ = 'Messages_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.Plots)
  ))
_sym_db.RegisterMessage(Plots)

XABSLSymbol = _reflection.GeneratedProtocolMessageType('XABSLSymbol', (_message.Message,), dict(
  DESCRIPTOR = _XABSLSYMBOL,
  __module__ = 'Messages_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.XABSLSymbol)
  ))
_sym_db.RegisterMessage(XABSLSymbol)

XABSLActiveOptionSparse = _reflection.GeneratedProtocolMessageType('XABSLActiveOptionSparse', (_message.Message,), dict(
  DESCRIPTOR = _XABSLACTIVEOPTIONSPARSE,
  __module__ = 'Messages_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.XABSLActiveOptionSparse)
  ))
_sym_db.RegisterMessage(XABSLActiveOptionSparse)

XABSLActionSparse = _reflection.GeneratedProtocolMessageType('XABSLActionSparse', (_message.Message,), dict(
  DESCRIPTOR = _XABSLACTIONSPARSE,
  __module__ = 'Messages_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.XABSLActionSparse)
  ))
_sym_db.RegisterMessage(XABSLActionSparse)

SymbolValueList = _reflection.GeneratedProtocolMessageType('SymbolValueList', (_message.Message,), dict(

  DoubleSymbol = _reflection.GeneratedProtocolMessageType('DoubleSymbol', (_message.Message,), dict(
    DESCRIPTOR = _SYMBOLVALUELIST_DOUBLESYMBOL,
    __module__ = 'Messages_pb2'
    # @@protoc_insertion_point(class_scope:naothmessages.SymbolValueList.DoubleSymbol)
    ))
  ,

  BooleanSymbol = _reflection.GeneratedProtocolMessageType('BooleanSymbol', (_message.Message,), dict(
    DESCRIPTOR = _SYMBOLVALUELIST_BOOLEANSYMBOL,
    __module__ = 'Messages_pb2'
    # @@protoc_insertion_point(class_scope:naothmessages.SymbolValueList.BooleanSymbol)
    ))
  ,

  EnumSymbol = _reflection.GeneratedProtocolMessageType('EnumSymbol', (_message.Message,), dict(
    DESCRIPTOR = _SYMBOLVALUELIST_ENUMSYMBOL,
    __module__ = 'Messages_pb2'
    # @@protoc_insertion_point(class_scope:naothmessages.SymbolValueList.EnumSymbol)
    ))
  ,
  DESCRIPTOR = _SYMBOLVALUELIST,
  __module__ = 'Messages_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.SymbolValueList)
  ))
_sym_db.RegisterMessage(SymbolValueList)
_sym_db.RegisterMessage(SymbolValueList.DoubleSymbol)
_sym_db.RegisterMessage(SymbolValueList.BooleanSymbol)
_sym_db.RegisterMessage(SymbolValueList.EnumSymbol)

BehaviorStateSparse = _reflection.GeneratedProtocolMessageType('BehaviorStateSparse', (_message.Message,), dict(
  DESCRIPTOR = _BEHAVIORSTATESPARSE,
  __module__ = 'Messages_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.BehaviorStateSparse)
  ))
_sym_db.RegisterMessage(BehaviorStateSparse)

BehaviorStateComplete = _reflection.GeneratedProtocolMessageType('BehaviorStateComplete', (_message.Message,), dict(

  EnumType = _reflection.GeneratedProtocolMessageType('EnumType', (_message.Message,), dict(

    Element = _reflection.GeneratedProtocolMessageType('Element', (_message.Message,), dict(
      DESCRIPTOR = _BEHAVIORSTATECOMPLETE_ENUMTYPE_ELEMENT,
      __module__ = 'Messages_pb2'
      # @@protoc_insertion_point(class_scope:naothmessages.BehaviorStateComplete.EnumType.Element)
      ))
    ,
    DESCRIPTOR = _BEHAVIORSTATECOMPLETE_ENUMTYPE,
    __module__ = 'Messages_pb2'
    # @@protoc_insertion_point(class_scope:naothmessages.BehaviorStateComplete.EnumType)
    ))
  ,

  Option = _reflection.GeneratedProtocolMessageType('Option', (_message.Message,), dict(

    State = _reflection.GeneratedProtocolMessageType('State', (_message.Message,), dict(
      DESCRIPTOR = _BEHAVIORSTATECOMPLETE_OPTION_STATE,
      __module__ = 'Messages_pb2'
      # @@protoc_insertion_point(class_scope:naothmessages.BehaviorStateComplete.Option.State)
      ))
    ,
    DESCRIPTOR = _BEHAVIORSTATECOMPLETE_OPTION,
    __module__ = 'Messages_pb2'
    # @@protoc_insertion_point(class_scope:naothmessages.BehaviorStateComplete.Option)
    ))
  ,

  Agent = _reflection.GeneratedProtocolMessageType('Agent', (_message.Message,), dict(
    DESCRIPTOR = _BEHAVIORSTATECOMPLETE_AGENT,
    __module__ = 'Messages_pb2'
    # @@protoc_insertion_point(class_scope:naothmessages.BehaviorStateComplete.Agent)
    ))
  ,
  DESCRIPTOR = _BEHAVIORSTATECOMPLETE,
  __module__ = 'Messages_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.BehaviorStateComplete)
  ))
_sym_db.RegisterMessage(BehaviorStateComplete)
_sym_db.RegisterMessage(BehaviorStateComplete.EnumType)
_sym_db.RegisterMessage(BehaviorStateComplete.EnumType.Element)
_sym_db.RegisterMessage(BehaviorStateComplete.Option)
_sym_db.RegisterMessage(BehaviorStateComplete.Option.State)
_sym_db.RegisterMessage(BehaviorStateComplete.Agent)

Module = _reflection.GeneratedProtocolMessageType('Module', (_message.Message,), dict(
  DESCRIPTOR = _MODULE,
  __module__ = 'Messages_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.Module)
  ))
_sym_db.RegisterMessage(Module)

ModuleList = _reflection.GeneratedProtocolMessageType('ModuleList', (_message.Message,), dict(
  DESCRIPTOR = _MODULELIST,
  __module__ = 'Messages_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.ModuleList)
  ))
_sym_db.RegisterMessage(ModuleList)

DebugRequest = _reflection.GeneratedProtocolMessageType('DebugRequest', (_message.Message,), dict(

  Item = _reflection.GeneratedProtocolMessageType('Item', (_message.Message,), dict(
    DESCRIPTOR = _DEBUGREQUEST_ITEM,
    __module__ = 'Messages_pb2'
    # @@protoc_insertion_point(class_scope:naothmessages.DebugRequest.Item)
    ))
  ,
  DESCRIPTOR = _DEBUGREQUEST,
  __module__ = 'Messages_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.DebugRequest)
  ))
_sym_db.RegisterMessage(DebugRequest)
_sym_db.RegisterMessage(DebugRequest.Item)

FeatureKeyPoint = _reflection.GeneratedProtocolMessageType('FeatureKeyPoint', (_message.Message,), dict(
  DESCRIPTOR = _FEATUREKEYPOINT,
  __module__ = 'Messages_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.FeatureKeyPoint)
  ))
_sym_db.RegisterMessage(FeatureKeyPoint)

FeatureDetectionResult = _reflection.GeneratedProtocolMessageType('FeatureDetectionResult', (_message.Message,), dict(
  DESCRIPTOR = _FEATUREDETECTIONRESULT,
  __module__ = 'Messages_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.FeatureDetectionResult)
  ))
_sym_db.RegisterMessage(FeatureDetectionResult)

SingleDescriptor = _reflection.GeneratedProtocolMessageType('SingleDescriptor', (_message.Message,), dict(
  DESCRIPTOR = _SINGLEDESCRIPTOR,
  __module__ = 'Messages_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.SingleDescriptor)
  ))
_sym_db.RegisterMessage(SingleDescriptor)

FeatureClass = _reflection.GeneratedProtocolMessageType('FeatureClass', (_message.Message,), dict(
  DESCRIPTOR = _FEATURECLASS,
  __module__ = 'Messages_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.FeatureClass)
  ))
_sym_db.RegisterMessage(FeatureClass)

FeatureTable = _reflection.GeneratedProtocolMessageType('FeatureTable', (_message.Message,), dict(
  DESCRIPTOR = _FEATURETABLE,
  __module__ = 'Messages_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.FeatureTable)
  ))
_sym_db.RegisterMessage(FeatureTable)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\031de.naoth.rc.core.messages'))
# @@protoc_insertion_point(module_scope)
